@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 Canonical Ltd.
+ * Copyright 2013-2014 Canonical Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of version 3 of the GNU Lesser General Public
@@ -17,7 +17,7 @@
  */
 
 #include <QCoreApplication>
-#include "./test_runner.h"
+#include <ubuntu/download_manager/tests/test_runner.h>
 
 int main(int argc, char *argv[]) {
     QCoreApplication a(argc, argv);
