@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 Canonical Ltd.
+ * Copyright 2013-2014 Canonical Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of version 3 of the GNU Lesser General Public
@@ -18,12 +18,14 @@
 
 #include <QTimer>
 #include <QCoreApplication>
-#include <download_daemon.h>
+#include <downloads/daemon.h>
+
+using namespace Ubuntu::DownloadManager::Daemon;
 
 int main(int argc, char *argv[]) {
     QCoreApplication a(argc, argv);
 
-    DownloadDaemon* daemon = new DownloadDaemon();
+    Daemon* daemon = new Daemon();
     // use a singleShot timer so that we start after exec so that exit works
     QTimer::singleShot(0, daemon, SLOT(start()));
 
